@@ -14,43 +14,43 @@ from telus_bulk.models.worker_job.place import PlaceAMS
 
 class AddressDetailModel(CamelModel):
     address_id: str
-    address_type: str
-    reference_id: ReferenceId
-    reference_ids: ReferenceIds
+    address_type: Optional[str]
+    reference_id: Optional[ReferenceId]
+    reference_ids: Optional[ReferenceIds]
     unit: Any
     floor: Any
     street_number_prefix: Any
-    street_number: str
+    street_number: Optional[str]
     street_number_suffix: Any
     dir_prefix: Any
     street_type_prefix: Any
-    street_name: str
+    street_name: Optional[str]
     street_type_suffix: Any
     dir_suffix: Any
-    city: str
+    city: Optional[str]
     province: str
     postal_code: Optional[str] = Field(default="N/A")
     country: Optional[Literal["USA", "CAN"]] = Field(default="CAN")
-    coid: str
-    serviceable: str
-    serviceable_code: str
-    building_type: str
-    premise_count_flag: Any
-    premise_count_date: Any
-    postal_code_updt_ts: Any
-    res_line_count: str
-    bus_line_count: str
-    mdu_sfu_count: str
-    project_sub_type: Any
-    first_nation_ind: str
-    exception_code: Any
-    nap_addr_assoc: Any
-    coordinate: Coordinate
-    zone_info: List[ZoneInfoItem]
-    fms_address: FmsAddress
-    e911_address: E911Address
-    tag: List
-    location_comments: Dict[str, Any]
+    coid: Optional[str]
+    serviceable: Optional[str]
+    serviceable_code: Optional[str]
+    building_type: Optional[str]
+    premise_count_flag: Optional[Any]
+    premise_count_date: Optional[Any]
+    postal_code_updt_ts: Optional[Any]
+    res_line_count: Optional[str]
+    bus_line_count: Optional[str]
+    mdu_sfu_count: Optional[str]
+    project_sub_type: Optional[Any]
+    first_nation_ind: Optional[str]
+    exception_code: Optional[Any]
+    nap_addr_assoc: Optional[Any]
+    coordinate: Optional[Coordinate]
+    zone_info: Optional[List[ZoneInfoItem]]
+    fms_address: Optional[FmsAddress]
+    e911_address: Optional[E911Address]
+    tag: Optional[List]
+    location_comments: Optional[Dict[str, Any]]
 
     def to_csq_item(self) -> PlaceAMS:
         return PlaceAMS(
